==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>الخطّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>خطّ واجهة المستخدم الافتراضيّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>اسم الخطّ:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>النّمط:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>حجم النّقطة:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>عاديّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>ثخين</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>مائل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>ثخين مائل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>ستؤثّر التّعديلات الآتية على التّطبيقات التي تبدأ بعد تطبيقها</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>استخدم خطوطًا محسّنة حوافها</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>نمط تلميحات الخطوط:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>قليل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>وسط</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>كامل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>تلميحات الخطوط</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>الميز (نقطة/بوصة):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>التلميحات آليّة</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>مضادّ تعرّج البكسلات الفرعيّة:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>ضبط لكسكيوت للمظهر</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>سمة الأيقونات</translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>سمة لكسكيوت</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="44"/>
        <source>LXQt Appearance Configuration</source>
        <translation>ضبط لكسكيوت للمظهر</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="50"/>
        <source>Widget Style</source>
        <translation>نمط الودجات</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="54"/>
        <source>Icons Theme</source>
        <translation>سمة الأيقونات</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="58"/>
        <source>LXQt Theme</source>
        <translation>سمة لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="62"/>
        <source>Font</source>
        <translation>الخطّ</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Cursor</source>
        <translation>المؤشّر</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>نمط الودجات</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>نمط زرّ شريط الأدوات:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>اعرض الأيقونة فقط</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>اعرض النّصّ فقط</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>يظهر النّصّ بجانب الأيقونة</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>يظهر النّصّ أسفل الأيقونة</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>الافتراضيّ</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>فعّل العنصر بالنّقر المفرد</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-appearance/lxqt-config-appearance_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../../../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>الخطّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>خطّ واجهة المستخدم الافتراضيّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>اسم الخطّ:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>النّمط:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="53"/>
        <source>Point size:</source>
        <translation>حجم النّقطة:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="68"/>
        <source>Normal</source>
        <translation>عاديّ</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="73"/>
        <source>Bold</source>
        <translation>ثخين</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="78"/>
        <source>Italic</source>
        <translation>مائل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="83"/>
        <source>Bold Italic</source>
        <translation>ثخين مائل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>ستؤثّر التّعديلات الآتية على التّطبيقات التي تبدأ بعد تطبيقها</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>استخدم خطوطًا محسّنة حوافها</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="107"/>
        <source>Font hinting style:</source>
        <translation>نمط تلميحات الخطوط:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="118"/>
        <location filename="../../../fontsconfig.ui" line="183"/>
        <source>None</source>
        <translation>بلا</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="123"/>
        <source>Slight</source>
        <translation>قليل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="128"/>
        <source>Medium</source>
        <translation>وسط</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="133"/>
        <source>Full</source>
        <translation>كامل</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="141"/>
        <source>Font hinting</source>
        <translation>تلميحات الخطوط</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="148"/>
        <source>Resolution (DPI):</source>
        <translation>الميز (نقطة/بوصة):</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="155"/>
        <source>Autohint</source>
        <translation>التلميحات آليّة</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="172"/>
        <source>Subpixel antialiasing:</source>
        <translation>مضادّ تعرّج البكسلات الفرعيّة:</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="188"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="193"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="198"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../../../fontsconfig.ui" line="203"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>ضبط لكسكيوت للمظهر</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation>سمة الأيقونات</translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation>سمة لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../lxqtthemeconfig.ui" line="57"/>
        <source>Override user-defined wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../main.cpp" line="57"/>
        <source>LXQt Appearance Configuration</source>
        <translation>ضبط لكسكيوت للمظهر</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="63"/>
        <source>Widget Style</source>
        <translation>نمط الودجات</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="67"/>
        <source>Icons Theme</source>
        <translation>سمة الأيقونات</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="71"/>
        <source>LXQt Theme</source>
        <translation>سمة لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="75"/>
        <source>Font</source>
        <translation>الخطّ</translation>
    </message>
    <message>
        <location filename="../../../main.cpp" line="80"/>
        <source>Cursor</source>
        <translation>المؤشّر</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../../../styleconfig.ui" line="23"/>
        <source>Widget Style</source>
        <translation>نمط الودجات</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="54"/>
        <source>Toolbar button style:</source>
        <translation>نمط زرّ شريط الأدوات:</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="62"/>
        <source>Only display the icon</source>
        <translation>اعرض الأيقونة فقط</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="67"/>
        <source>Only display the text</source>
        <translation>اعرض النّصّ فقط</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="72"/>
        <source>The text appears beside the icon</source>
        <translation>يظهر النّصّ بجانب الأيقونة</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="77"/>
        <source>The text appears under the icon</source>
        <translation>يظهر النّصّ أسفل الأيقونة</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="82"/>
        <source>Default</source>
        <translation>الافتراضيّ</translation>
    </message>
    <message>
        <location filename="../../../styleconfig.ui" line="90"/>
        <source>Activate item on single click</source>
        <translation>فعّل العنصر بالنّقر المفرد</translation>
    </message>
</context>
</TS>
